@@ -54,8 +54,8 @@ Based on Telepathy-SNOM with copyright notice below.
 #define APPLICATION_DBUS_SERVICE        "org.maemo." TP_NAME
 
 #define TP_CHANNEL          TP_PATH_DOT ".Channel"
-#define TP_CHANNEL_PATH     TP_PATH_SLASH "/Channel"
-
-#define TP_STREAMEDMEDIA    TP_CHANNEL ".Type.StreamedMedia"
+#define TP_CHANNEL_TYPE     TP_CHANNEL ".Type"
+#define TP_STREAMEDMEDIA    TP_CHANNEL_TYPE ".StreamedMedia"
+#define TP_TEXTMEDIA        TP_CHANNEL_TYPE ".Text"
 
 #endif //_QGVTP_NAMES_H_
